Name: lapack
Version: 3.1.1
Release: alt1
Epoch: 1

Summary: The BLAS and LAPACK Fortran libraries for numerical linear algebra
License: BSD
Group: Development/Other

URL: http://www.netlib.org/
Source: lapack-%version-%release.tar

# Automatically added by buildreq on Wed Apr 18 2007
BuildRequires: gcc-fortran libatlas-devel

%package -n lib%name
Summary: The BLAS and LAPACK Fortran libraries for numerical linear algebra
Group: System/Libraries

%package -n lib%name-devel
Summary: The BLAS and LAPACK Fortran libraries for numerical linear algebra
Group: Development/Other
Requires: libatlas-devel
Requires: lib%name = %epoch:%version-%release
Provides: %name = %version

%description
LAPACK (Linear Algebra PACKage) is a standard library for numerical
linear algebra. LAPACK provides routines for solving systems of
simultaneous linear equations, least-squares solutions of linear
systems of equations, eigenvalue problems, and singular value
problems. Associated matrix factorizations (LU, Cholesky, QR, SVD,
Schur, and generalized Schur) and related computations (i.e.,
reordering of Schur factorizations and estimating condition numbers)
are also included. LAPACK can handle dense and banded matrices, but
not general sparse matrices. Similar functionality is provided for
real and complex matrices in both single and double precision.

%description -n lib%name
LAPACK (Linear Algebra PACKage) is a standard library for numerical
linear algebra. LAPACK provides routines for solving systems of
simultaneous linear equations, least-squares solutions of linear
systems of equations, eigenvalue problems, and singular value
problems. Associated matrix factorizations (LU, Cholesky, QR, SVD,
Schur, and generalized Schur) and related computations (i.e.,
reordering of Schur factorizations and estimating condition numbers)
are also included. LAPACK can handle dense and banded matrices, but
not general sparse matrices. Similar functionality is provided for
real and complex matrices in both single and double precision.

%description -n lib%name-devel
LAPACK (Linear Algebra PACKage) is a standard library for numerical
linear algebra. LAPACK provides routines for solving systems of
simultaneous linear equations, least-squares solutions of linear
systems of equations, eigenvalue problems, and singular value
problems. Associated matrix factorizations (LU, Cholesky, QR, SVD,
Schur, and generalized Schur) and related computations (i.e.,
reordering of Schur factorizations and estimating condition numbers)
are also included. LAPACK can handle dense and banded matrices, but
not general sparse matrices. Similar functionality is provided for
real and complex matrices in both single and double precision.

This package includes manual pages for the BLAS and LAPACK routines.

%prep
%setup -q -n lapack-%version-%release

[ -f manpages/blas/man/manl/xerbla.l ]
rm manpages/man/manl/xerbla.l

%build
# whether to use the ALTAS optimized routines
%def_with atlas
%define soname liblapack.so.3

# for rpm -bc --short-circuit, rebuild test suite with liblapack.a
rm -f TESTING/x*

make
grep -r --include='*.out' -i fail . |tee 1.err

# liblapack.a is now ready; if we use the ATLAS optimized routines,
# we want to exclude certain *.o from the shared library and make it
# link with -llapack_atlas

%if_with atlas
rm -f *.o
ar x liblapack.a
nm -D %_libdir/liblapack_atlas.so %_libdir/libblas.so >sym
awk 'NF==3&&sub(/_$/,"",$3)&&$3!~/_/{print$3".o"}' <sym >dups
rm -fv `sort -u dups`
g77 -shared *.o \
	-o %soname -Wl,-soname=%soname -Wl,--version-script=liblapack.map \
	-llapack_atlas -lblas -Wl,-z,defs
rm *.o

# rerun test suite against the shared library combo
rm TESTING/x*
LD_LIBRARY_PATH=$PWD make -C TESTING LAPACKLIB='%soname -llapack_atlas'
grep -r --include='*.out' -i fail . |tee 2.err

%else # without atlas
g77 -shared -Wl,--whole-archive liblapack.a -Wl,--no-whole-archive \
	-o %soname -Wl,-soname=%soname -Wl,--version-script=liblapack.map \
	-lblas -Wl,-z,defs
%endif

%install
install -pD -m755 %soname %buildroot%_libdir/%soname
%if_with atlas
cat >%buildroot%_libdir/liblapack.so <<EOF
GROUP( %_libdir/%soname %_libdir/liblapack_atlas.so
	AS_NEEDED( %_libdir/libblas.so ) )
EOF
%else
ln -s %soname %buildroot%_libdir/liblapack.so
%endif

for f in manpages/blas/man/manl/*.l; do
	m=$(basename "$f" .l).3f
	install -pD -m644 $f %buildroot%_man3dir/"$m"
	echo %_man3dir/"$m*"
done >blas-man.files

for f in manpages/man/manl/*.l; do
	m=$(basename "$f" .l).3f
	install -pD -m644 $f %buildroot%_man3dir/"$m"
	echo %_man3dir/"$m*"
done >lapack-man.files

%post -n lib%name -p %post_ldconfig
%postun -n lib%name -p %postun_ldconfig

%files -n lib%name
%define _customdocdir %_docdir/lapack-3.1
%doc COPYING README lapack-*.changes
%_libdir/%soname

%files -n lib%name-devel
%_libdir/liblapack.so
%_man3dir/*.3*

%changelog
* Thu Apr 19 2007 Alexey Tourbin <at@altlinux.ru> 1:3.1.1-alt1
- 3.1.0 -> 3.1.1
- changed manual page suffix from .3 to .3f

* Wed Dec 13 2006 Alexey Tourbin <at@altlinux.ru> 1:3.1.0-alt1
- 3.0 -> 3.1.0
- imported sources into git and adapted for gear
- packaged COPYING README lapack-3.1.0.changes
- changed License from "Distributable" to "BSD" (see COPYING)
- added version script for liblapack.so.3 (new routines under LAPACK_3.1)
- made use of makefiles again and made build process execute test suite
- compiled with default optimization flags instead of -Os

* Tue Jun 06 2006 Alexey Tourbin <at@altlinux.ru> 1:3.0-alt3
- rebuilt with -llapack_atlas -lblas from ATLAS
- enabled tesing (i586 only, xlintsts hangs on x86_64)

* Sat Jun 03 2006 Alexey Tourbin <at@altlinux.ru> 1:3.0-alt2
- rebuilt with gfortran

* Tue Apr 25 2006 Alexey Tourbin <at@altlinux.ru> 1:3.0-alt1
- back to official versioning
- use officially released tarball
- libification: lib%name, lib%name-devel, lib%name-devel-static
- abandon makefiles, custom %%build procedure
- compile with -Os to workaround g77 bugs (redhat #138447)
- complie dcabs1.f with -O0 (redhat #143420)
- added missing BLAS source files (drotm.f, drotmg.f, zdrot.f, etc.)
- added manual pages to lib%name-devel

* Sun Dec 01 2002 Vitaly Lugovsky <vsl@altlinux.ru> 2002-alt3
- rebuild

* Tue May 14 2002 Vitaly Lugovsky <vsl@altlinux.ru> 2002-alt2
- First release. It's generally needed by CERNLib, so we've
  only static version here.
